/* Copyright (C) 2005 Timo Sirainen */

#include "lib.h"
#include "mail-storage.h"
#include "quota.h"
#include "quota-plugin.h"

#include <stdlib.h>

/* defined by imap, pop3, lda */
extern void (*hook_mail_storage_created)(struct mail_storage *storage);

void (*quota_next_hook_mail_storage_created)(struct mail_storage *storage);

const char *quota_plugin_version = PACKAGE_VERSION;
struct quota *quota_set;

void quota_plugin_init(void)
{
	const char *env;

	env = getenv("QUOTA");
	if (env != NULL) {
		struct quota_setup *setup;
		const char *name;
		unsigned int i;
		quota_set = quota_init();
		/* Currently we support only one quota setup */
		setup = quota_setup_init(quota_set, env, TRUE);

		name = "QUOTA_WARNING";
		env = getenv(name);
		i = 1;
		t_push();
		while (env != NULL) {
			(void)quota_warning_init(setup, env);

			name = t_strdup_printf("QUOTA_WARNING%u", ++i);
			env = getenv(name);
		}
		t_pop();

		quota_next_hook_mail_storage_created =
			hook_mail_storage_created;
		hook_mail_storage_created = quota_mail_storage_created;
	}
}

void quota_plugin_deinit(void)
{
	if (quota_set != NULL) {
		hook_mail_storage_created =
			quota_next_hook_mail_storage_created;
		quota_deinit(quota_set);
	}
}
